@@ -21,11 +21,12 @@ from exponent.core.config import (
     get_settings,
 )
 from exponent.core.graphql.client import GraphQLClient
-from exponent.core.graphql.mutations import (
-    CREATE_CLOUD_CHAT_MUTATION,
-    REFRESH_API_KEY_MUTATION,
-    SET_LOGIN_COMPLETE_MUTATION,
-    START_CHAT_TURN_MUTATION,
+from exponent.core.graphql.generated_client import (
+    ReportSandboxInfoReportSandboxInfoError,
+    ReportSandboxInfoReportSandboxInfoSandboxInfoResponse,
+    ReportSandboxInfoReportSandboxInfoUnauthenticatedError,
+    SetLoginCompleteSetLoginCompleteUnauthenticatedError,
+    SetLoginCompleteSetLoginCompleteUser,
 )
 from exponent.core.remote_execution.client import (
     REMOTE_EXECUTION_CLIENT_EXIT_INFO,
@@ -153,7 +154,7 @@ async def check_inside_git_repo(settings: Settings) -> None:
 
         if not click.confirm(
             click.style(
-                f"\nDo you want to continue running Exponent from {os.getcwd()}?",
+                f"\nDo you want to continue running Indent from {os.getcwd()}?",
                 fg="yellow",
             ),
             default=True,
@@ -235,29 +236,6 @@ def run_until_complete(coro: Coroutine[Any, Any, Any]) -> Any:
         sys.exit(1)
 
 
-async def create_cloud_chat(
-    api_key: str, base_api_url: str, base_ws_url: str, config_uuid: str
-) -> str:
-    graphql_client = GraphQLClient(
-        api_key=api_key, base_api_url=base_api_url, base_ws_url=base_ws_url
-    )
-
-    variables = {
-        "configId": config_uuid,
-    }
-
-    result = await graphql_client.execute(
-        CREATE_CLOUD_CHAT_MUTATION, variables, "CreateCloudChat", timeout=120
-    )
-
-    data = result["createCloudChat"]
-
-    if data["__typename"] != "Chat":
-        raise HandledExponentError(f"Error creating cloud chat: {data['message']}")
-
-    return str(data["chatUuid"])
-
-
 async def start_chat_turn(
     api_key: str, base_api_url: str, base_ws_url: str, chat_uuid: str, prompt: str
 ) -> None:
@@ -265,25 +243,20 @@ async def start_chat_turn(
         api_key=api_key, base_api_url=base_api_url, base_ws_url=base_ws_url
     )
 
-    variables = {
-        "chatInput": {"prompt": {"message": prompt, "attachments": []}},
-        "parentUuid": None,
-        "chatConfig": {
-            "chatUuid": chat_uuid,
-            "exponentModel": "PREMIUM",
-            "requireConfirmation": False,
-            "readOnly": False,
-            "depthLimit": 20,
-        },
-    }
-    result = await graphql_client.execute(
-        START_CHAT_TURN_MUTATION, variables, "StartChatTurnMutation"
+    result = await graphql_client.start_chat_turn(
+        chat_uuid=chat_uuid,
+        prompt=prompt,
+        parent_uuid=None,
+        exponent_model="PREMIUM",
+        require_confirmation=False,
+        read_only=False,
+        depth_limit=20,
     )
 
-    data = result["startChatReply"]
-
-    if data["__typename"] != "Chat":
-        raise HandledExponentError(f"Error starting chat turn: {data['message']}")
+    if result.start_chat_reply.typename__ != "Chat":
+        raise HandledExponentError(
+            f"Error starting chat turn: {getattr(result.start_chat_reply, 'message', 'Unknown error')}"
+        )
 
 
 async def run_workflow(
@@ -363,21 +336,24 @@ async def set_login_complete(api_key: str, base_api_url: str, base_ws_url: str)
     graphql_client = GraphQLClient(
         api_key=api_key, base_api_url=base_api_url, base_ws_url=base_ws_url
     )
-    result = await graphql_client.execute(
-        SET_LOGIN_COMPLETE_MUTATION, {}, "SetLoginComplete"
-    )
+    result = await graphql_client.set_login_complete()
 
-    data = result["setLoginComplete"]
+    data = result.set_login_complete
 
-    if data["__typename"] == "UnauthenticatedError":
-        raise HandledExponentError(f"Verification failed: {data['message']}")
+    if isinstance(data, SetLoginCompleteSetLoginCompleteUnauthenticatedError):
+        raise HandledExponentError(f"Verification failed: {data.message}")
 
-    if data["userApiKey"] != api_key:
-        # We got a user object back, but the api_key is different
-        # than the one used in the user's request...
-        # This should never happen
+    if isinstance(data, SetLoginCompleteSetLoginCompleteUser):
+        if data.user_api_key != api_key:
+            # We got a user object back, but the api_key is different
+            # than the one used in the user's request...
+            # This should never happen
+            raise HandledExponentError(
+                "Invalid API key, login to https://indent.com to find your API key."
+            )
+    else:
         raise HandledExponentError(
-            "Invalid API key, login to https://indent.com to find your API key."
+            f"Unexpected response type from setLoginComplete: {type(data).__name__}"
         )
 
 
@@ -387,28 +363,67 @@ async def refresh_api_key_task(
     base_ws_url: str,
 ) -> None:
     graphql_client = GraphQLClient(api_key, base_api_url, base_ws_url)
-    result = await graphql_client.execute(REFRESH_API_KEY_MUTATION)
+    result = await graphql_client.refresh_api_key()
 
-    if "refreshApiKey" in result:
-        if "message" in result["refreshApiKey"]:
-            # Handle error case
-            click.secho(f"Error: {result['refreshApiKey']['message']}", fg="red")
-            return
+    # Handle error case
+    if result.refresh_api_key.typename__ == "UnauthenticatedError":
+        click.secho(f"Error: {result.refresh_api_key.message}", fg="red")
+        return
 
-        if "userApiKey" in result["refreshApiKey"]:
-            # Handle success case
-            new_api_key = result["refreshApiKey"]["userApiKey"]
-            settings = get_settings()
+    # Handle success case
+    if result.refresh_api_key.typename__ == "User":
+        new_api_key = result.refresh_api_key.user_api_key
+        settings = get_settings()
 
-            click.echo(f"Saving new API Key to {settings.config_file_path}")
-            settings.update_api_key(new_api_key)
-            settings.write_settings_to_config_file()
+        click.echo(f"Saving new API Key to {settings.config_file_path}")
+        settings.update_api_key(new_api_key)
+        settings.write_settings_to_config_file()
 
-            click.secho(
-                "API key has been refreshed and saved successfully!", fg="green"
-            )
-            return
+        click.secho("API key has been refreshed and saved successfully!", fg="green")
+        return
 
-    # Handle unexpected response
-    click.secho("Failed to refresh API key: Unexpected response", fg="red")
-    click.echo(result)
+
+async def report_sandbox_info(
+    api_key: str,
+    base_api_url: str,
+    base_ws_url: str,
+    sandbox_id: str,
+    disk_usage_gb: float | None = None,
+    indent_log_file: str | None = None,
+) -> None:
+    """Report sandbox metrics to the backend for monitoring.
+
+    Args:
+        api_key: User's API key
+        base_api_url: Base API URL
+        base_ws_url: Base WebSocket URL
+        sandbox_id: Sandbox identifier
+        disk_usage_gb: Disk usage in GB
+        indent_log_file: Path to the indent CLI log file
+
+    Raises:
+        HandledExponentError: If the mutation fails
+    """
+    graphql_client = GraphQLClient(
+        api_key=api_key, base_api_url=base_api_url, base_ws_url=base_ws_url
+    )
+
+    result = await graphql_client.report_sandbox_info(
+        sandbox_id=sandbox_id,
+        disk_usage_gb=disk_usage_gb,
+        indent_log_file=indent_log_file,
+    )
+
+    data = result.report_sandbox_info
+
+    if isinstance(data, ReportSandboxInfoReportSandboxInfoUnauthenticatedError):
+        raise HandledExponentError(f"Authentication failed: {data.message}")
+
+    if isinstance(data, ReportSandboxInfoReportSandboxInfoError):
+        raise HandledExponentError(f"Failed to report sandbox info: {data.message}")
+
+    if not isinstance(data, ReportSandboxInfoReportSandboxInfoSandboxInfoResponse):
+        raise HandledExponentError("Failed to report sandbox info: Unexpected response")
+
+    if not data.success:
+        raise HandledExponentError(f"Failed to report sandbox info: {data.message}")
