@@ -11,8 +11,10 @@ class BuildLogOutput(msgspec.Struct, tag="container_build_log_output"):
     container_image_uuid: str
     data: str
     timestamp: float
+    phase: Literal[
+        "verification", "setup_repo", "build_script", "run_script", "complete_build"
+    ] = "build_script"
     level: Literal["info", "error", "warning"] = "info"
-    phase: Literal["build", "verification"] = "build"
     command: str | None = None
 
 
@@ -21,6 +23,7 @@ class BuildLogStatus(msgspec.Struct, tag="container_build_log_status"):
 
     container_image_uuid: str
     status: Literal["started", "completed", "failed"]
+    timestamp: float
     message: str | None = None
 
 
