@@ -1,26 +1,3 @@
-GITHUB_REPOSITORIES_QUERY: str = """
-query GithubRepositories {
-  githubRepositories {
-    __typename
-    ... on GithubRepositories {
-      repositories {
-        id
-        githubOrgName
-        githubRepoName
-        baseHost
-        containerImageId
-        createdAt
-        updatedAt
-      }
-    }
-    ... on Error {
-      message
-    }
-  }
-}
-"""
-
-
 EVENTS_FOR_CHAT_QUERY: str = """query EventsForChat($chatUuid: UUID!) {
   eventsForChat(chatUuid: $chatUuid) {
     ... on EventHistory {
