@@ -1,3 +1,4 @@
+import base64
 from typing import TYPE_CHECKING, Any
 
 import msgspec
@@ -74,6 +75,32 @@ class ReadToolArtifactResult(ToolResult, tag=READ_TOOL_ARTIFACT_NAME):
     def to_text(self) -> str:
         return f"[Image artifact uploaded to {self.s3_uri}]"
 
+    async def get_base64_content(self, chat_uuid: str) -> str:
+        """Download the artifact from S3 and return as base64-encoded string.
+
+        Args:
+            chat_uuid: The chat UUID for S3 client scoping
+
+        Returns:
+            Base64-encoded string of the file content
+        """
+        from exponent_server.core.services.modal.s3 import S3Client
+
+        s3_client = S3Client(chat_uuid=chat_uuid)
+        await s3_client.authenticate()
+
+        s3_uri = self.s3_uri
+        bucket_prefix = f"s3://{s3_client.bucket_name}/"
+        if s3_uri.startswith(bucket_prefix):
+            s3_key = s3_uri[len(bucket_prefix) :]
+            chat_prefix = f"{chat_uuid}/"
+            if s3_key.startswith(chat_prefix):
+                s3_key = s3_key[len(chat_prefix) :]
+
+        # Download file directly to memory
+        file_bytes = await s3_client.get_object(s3_key)
+        return base64.standard_b64encode(file_bytes).decode("utf-8")
+
 
 class ReadToolResult(ToolResult, tag=READ_TOOL_NAME):
     content: str | None = None
