@@ -526,13 +526,8 @@ class RemoteExecutionClient:
                             )
 
         beat_task = asyncio.create_task(beat())
-        # Three parallel executors to handle requests
-
-        executor_tasks = [
-            asyncio.create_task(executor()),
-            asyncio.create_task(executor()),
-            asyncio.create_task(executor()),
-        ]
+        # Ten parallel executors to handle requests
+        executor_tasks = [asyncio.create_task(executor()) for _ in range(10)]
 
         return [beat_task, *executor_tasks]
 
@@ -631,6 +626,9 @@ class RemoteExecutionClient:
                 terminal_output_queue,
                 terminal_session_manager,
             )
+        except asyncio.CancelledError:
+            # Re-raise CancelledError to allow proper task cancellation
+            raise
         except websockets.exceptions.ConnectionClosed as e:
             if e.rcvd is not None:
                 if e.rcvd.code == 1000:
