@@ -1,4 +1,5 @@
 import asyncio
+import codecs
 import os
 import platform
 import shutil
@@ -11,7 +12,6 @@ from exponent.core.remote_execution.languages.types import (
     ShellExecutionResult,
     StreamedOutputPiece,
 )
-from exponent.core.remote_execution.utils import smart_decode
 
 STDOUT_FD = 1
 STDERR_FD = 2
@@ -45,31 +45,24 @@ def get_rc_file_source_command(shell_path: str) -> str:
 async def read_stream(
     stream: asyncio.StreamReader, fd: int, output: list[tuple[int, str]]
 ) -> AsyncGenerator[StreamedOutputPiece, None]:
-    data: bytes = b""
-    encoding = "utf-8"
+    # Use an incremental decoder to properly handle multi-byte UTF-8 sequences
+    # that may be split across read boundaries
+    decoder = codecs.getincrementaldecoder("utf-8")(errors="replace")
 
     while True:
         try:
             data = await stream.read(50_000)
             if not data:
+                # Flush any remaining bytes in decoder
+                chunk = decoder.decode(b"", final=True)
+                if chunk:
+                    output.append((fd, chunk))
+                    yield StreamedOutputPiece(content=chunk)
                 break
-            chunk = data.decode(encoding=encoding, errors="replace")
-            output.append((fd, chunk))
-            yield StreamedOutputPiece(content=chunk)
-        except UnicodeDecodeError:
-            decode_result = smart_decode(data)
-
-            if decode_result is None:
-                break
-
-            # Store the detected encoding as a hint for how
-            # to decode the remaining chunks of data
-            chunk, encoding = decode_result
-
-            output.append((fd, chunk))
-            yield StreamedOutputPiece(content=chunk)
-
-            continue
+            chunk = decoder.decode(data, final=False)
+            if chunk:
+                output.append((fd, chunk))
+                yield StreamedOutputPiece(content=chunk)
         except asyncio.CancelledError:
             raise
         except Exception:
