@@ -3,18 +3,20 @@ import codecs
 import fcntl
 import logging
 import os
+import shlex
+import shutil
 import signal
 import struct
 import sys
 import termios
 import time
 import traceback
-from collections.abc import Callable
 
 from exponent.core.remote_execution.terminal_types import (
     TerminalMessage,
     TerminalOutput,
     TerminalResetSessions,
+    TerminalStatus,
 )
 
 logger = logging.getLogger(__name__)
@@ -29,12 +31,12 @@ class TerminalSession:
     def __init__(
         self,
         session_id: str,
-        output_callback: Callable[[str], None],
+        output_queue: asyncio.Queue[TerminalMessage],
         cols: int = 80,
         rows: int = 24,
     ):
         self.session_id = session_id
-        self.output_callback = output_callback  # Called with terminal output
+        self.output_queue = output_queue
         self.cols = cols
         self.rows = rows
         self.master_fd: int | None = None
@@ -42,6 +44,13 @@ class TerminalSession:
         self._running = False
         self._read_task: asyncio.Task[None] | None = None
 
+    def _queue_message(self, message: TerminalMessage) -> None:
+        """Helper to queue terminal messages with error handling."""
+        try:
+            self.output_queue.put_nowait(message)
+        except asyncio.QueueFull:
+            logger.error("Terminal output queue full")
+
     def _cleanup_fds(self, master_fd: int | None, slave_fd: int | None) -> None:
         """Clean up file descriptors on error."""
         if master_fd is not None:
@@ -56,7 +65,11 @@ class TerminalSession:
                 pass
 
     def _setup_child_process(
-        self, slave_fd: int, command: list[str], env: dict[str, str] | None
+        self,
+        slave_fd: int,
+        shell_path: str,
+        commands: list[str] | None,
+        env: dict[str, str] | None,
     ) -> None:
         """Set up child process with PTY slave as controlling terminal."""
         # Create new session and set controlling terminal
@@ -89,7 +102,16 @@ class TerminalSession:
         os.environ.pop("TERM_PROGRAM_VERSION", None)
 
         # Execute command
-        os.execvp(command[0], command)
+        if commands:
+            # Run command, then replace with a new interactive shell
+            cmd_string = " ".join(shlex.quote(c) for c in commands)
+            os.execvp(
+                shell_path,
+                [shell_path, "-l", "-c", f"{cmd_string}; exec {shell_path} -l"],
+            )
+        else:
+            # Just start interactive shell
+            os.execvp(shell_path, [shell_path])
 
     async def start(  # noqa: PLR0915
         self,
@@ -101,10 +123,12 @@ class TerminalSession:
             raise RuntimeError(f"Terminal session {self.session_id} already running")
 
         # Default to user's shell if no command specified
-        if command is None:
-            # Get user's default shell from environment, fallback to /bin/bash
-            default_shell = os.environ.get("SHELL", "/bin/bash")
-            command = [default_shell]
+        default_shell = (
+            os.environ.get("SHELL")
+            or shutil.which("bash")
+            or shutil.which("sh")
+            or "/bin/sh"
+        )
 
         # Create PTY with window size set BEFORE fork to eliminate race condition
         master_fd = None
@@ -132,7 +156,7 @@ class TerminalSession:
         if self.pid == 0:
             # Child process - set up PTY slave as controlling terminal
             try:
-                self._setup_child_process(slave_fd, command, env)
+                self._setup_child_process(slave_fd, default_shell, command, env)
             except Exception as e:
                 # If exec fails, log and exit child process
                 traceback.print_exc()
@@ -230,13 +254,24 @@ class TerminalSession:
             self._running = True
             self._read_task = asyncio.create_task(self._read_from_pty())
 
+            # Send started status message
+            self._queue_message(
+                TerminalStatus(
+                    session_id=self.session_id,
+                    status="started",
+                    message="Terminal session started",
+                    exit_code=None,
+                )
+            )
+
     async def _read_from_pty(self) -> None:
         """Continuously read from PTY using event loop's add_reader (non-blocking)"""
         if self.master_fd is None:
             return
 
         loop = asyncio.get_event_loop()
-        read_queue: asyncio.Queue[bytes | None] = asyncio.Queue()
+        decoder = codecs.getincrementaldecoder("utf-8")(errors="replace")
+        eof_event = asyncio.Event()
 
         def read_callback() -> None:
             """Called by event loop when data is available on the FD"""
@@ -245,50 +280,78 @@ class TerminalSession:
             try:
                 data = os.read(self.master_fd, 4096)
                 if data:
-                    # Put data in queue to be processed by async task
-                    read_queue.put_nowait(data)
+                    # Decode and queue output directly
+                    decoded = decoder.decode(data, final=False)
+                    if decoded:
+                        self._queue_message(
+                            TerminalOutput(
+                                session_id=self.session_id,
+                                data=decoded,
+                                timestamp=time.time(),
+                            )
+                        )
                 else:
                     # EOF - PTY closed
-                    read_queue.put_nowait(None)
+                    eof_event.set()
             except OSError as e:
                 if e.errno == 11:  # EAGAIN - shouldn't happen with add_reader
                     pass
                 else:
-                    read_queue.put_nowait(None)
+                    eof_event.set()
             except Exception:
                 logger.error(
                     "Unexpected error in PTY read callback",
                 )
-                read_queue.put_nowait(None)
+                eof_event.set()
 
         # Register the FD with the event loop
         loop.add_reader(self.master_fd, read_callback)
 
-        # Use incremental decoder to handle partial UTF-8 sequences
-
-        decoder = codecs.getincrementaldecoder("utf-8")(errors="replace")
-
         try:
-            while self._running:
-                # Wait for data from the queue (non-blocking for event loop)
-                data = await read_queue.get()
+            # Wait for EOF
+            await eof_event.wait()
 
-                if data is None:
-                    # EOF or error - flush any remaining bytes in decoder
-                    final = decoder.decode(b"", final=True)
-                    if final:
-                        self.output_callback(final)
-                    break
-
-                # Process the data with incremental decoder
-                # This handles partial UTF-8 sequences correctly
-                decoded = decoder.decode(data, final=False)
-                if decoded:
-                    self.output_callback(decoded)
+            # Flush any remaining bytes in decoder
+            final = decoder.decode(b"", final=True)
+            if final:
+                self._queue_message(
+                    TerminalOutput(
+                        session_id=self.session_id,
+                        data=final,
+                        timestamp=time.time(),
+                    )
+                )
         finally:
             # Unregister the FD from the event loop
             loop.remove_reader(self.master_fd)
 
+            # If we got stopped by stop we don't need to emit an exit again
+            if self._running:
+                # Mark as not running
+                self._running = False
+
+                # Terminal exited naturally (e.g., user typed 'exit')
+                # Wait for child process to get exit code
+                exit_code = None
+                if self.pid is not None:
+                    try:
+                        # Try to get exit status
+                        pid, status = os.waitpid(self.pid, os.WNOHANG)
+                        if pid != 0:
+                            exit_code = os.WEXITSTATUS(status)
+                    except ChildProcessError:
+                        pass
+
+                # Send exited status message
+                self._queue_message(
+                    TerminalStatus(
+                        session_id=self.session_id,
+                        status="exited",
+                        message="Terminal session exited",
+                        exit_code=exit_code,
+                    )
+                )
+
     async def write_input(self, data: str) -> None:
         """Write user input to PTY"""
         if not self._running or self.master_fd is None:
@@ -379,12 +442,18 @@ class TerminalSession:
             "Terminal session stopped",
         )
 
-        return True, exit_code
+        # Send terminal status message (only if not already sent by _read_from_pty)
+        # This handles the case where stop() is called explicitly
+        self._queue_message(
+            TerminalStatus(
+                session_id=self.session_id,
+                status="exited",
+                message="Terminal session exited",
+                exit_code=exit_code,
+            )
+        )
 
-    @property
-    def is_running(self) -> bool:
-        """Check if terminal session is running"""
-        return self._running and self.master_fd is not None
+        return True, exit_code
 
 
 class TerminalSessionManager:
@@ -425,24 +494,9 @@ class TerminalSessionManager:
             # Store websocket reference
             self._websocket = websocket
 
-            # Create output callback that queues data to be sent
-            def output_callback(data: str) -> None:
-                # Queue the output to be sent asynchronously
-                try:
-                    terminal_output = TerminalOutput(
-                        session_id=session_id,
-                        data=data,
-                        timestamp=time.time(),
-                    )
-                    self._output_queue.put_nowait(terminal_output)
-                except asyncio.QueueFull:
-                    logger.error(
-                        "Terminal output queue full",
-                    )
-
             session = TerminalSession(
                 session_id=session_id,
-                output_callback=output_callback,
+                output_queue=self._output_queue,
                 cols=cols,
                 rows=rows,
             )
@@ -513,6 +567,6 @@ class TerminalSessionManager:
                             "Stopped terminal session on cleanup",
                         )
                     except Exception:
-                        logger.error(
+                        logger.exception(
                             "Error stopping terminal session on cleanup",
                         )
