@@ -1,5 +1,7 @@
 """Type definitions for terminal output streaming."""
 
+from typing import Literal
+
 import msgspec
 
 
@@ -15,7 +17,7 @@ class TerminalStatus(msgspec.Struct, tag="terminal_status"):
     """Terminal status update from CLI to web client."""
 
     session_id: str
-    status: str
+    status: Literal["started", "exited"]
     message: str
     exit_code: int | None = None
 
