@@ -563,13 +563,14 @@ class ChatMode(str, Enum):
     DEFAULT = "DEFAULT"  # chat just with model
     CLI = "CLI"
     CLOUD = "CLOUD"  # chat with cloud devbox
+    CLOUD_SETUP = "CLOUD_SETUP"  # cloud environment setup
     CODEBASE = "CODEBASE"  # chat with codebase
     DATABASE = "DATABASE"  # chat with database connection
     WORKFLOW = "WORKFLOW"
 
     @classmethod
     def requires_cli(cls, mode: "ChatMode") -> bool:
-        return mode not in [cls.DATABASE]
+        return mode not in [cls.DATABASE, cls.CLOUD_SETUP]
 
 
 class ChatSource(str, Enum):
@@ -580,6 +581,7 @@ class ChatSource(str, Enum):
     VSCODE_EXTENSION = "VSCODE_EXTENSION"
     SLACK_APP = "SLACK_APP"
     SENTRY_APP = "SENTRY_APP"
+    GITHUB_APP = "GITHUB_APP"
 
 
 class CLIConnectedState(BaseModel):
