@@ -1,5 +1,6 @@
 import json
 import logging
+import stat
 from collections.abc import Awaitable, Callable
 from functools import wraps
 from typing import (
@@ -22,6 +23,7 @@ from sentry_sdk.utils import (
     exc_info_from_error,
 )
 
+from exponent.core.remote_execution.cli_rpc_types import FileMetadata
 from exponent.core.remote_execution.types import (
     SUPPORTED_LANGUAGES,
     CLIErrorLog,
@@ -29,42 +31,24 @@ from exponent.core.remote_execution.types import (
     CodeExecutionResponse,
     CommandRequest,
     CommandResponse,
-    CreateCheckpointRequest,
     CreateCheckpointResponse,
     ErrorResponse,
     FilePath,
     FileWriteRequest,
     FileWriteResponse,
-    GetAllTrackedFilesRequest,
-    GetAllTrackedFilesResponse,
-    GetFileAttachmentRequest,
-    GetFileAttachmentResponse,
-    GetFileAttachmentsRequest,
-    GetFileAttachmentsResponse,
-    GetMatchingFilesRequest,
-    GetMatchingFilesResponse,
-    HaltRequest,
-    HaltResponse,
     ListFilesRequest,
     ListFilesResponse,
     RemoteExecutionMessage,
     RemoteExecutionMessageData,
     RemoteExecutionRequest,
-    RemoteExecutionRequestData,
     RemoteExecutionRequestType,
     RemoteExecutionResponse,
     RemoteExecutionResponseData,
     RemoteExecutionResponseType,
-    RollbackToCheckpointRequest,
     RollbackToCheckpointResponse,
-    StreamingCodeExecutionRequest,
     StreamingCodeExecutionResponse,
     StreamingCodeExecutionResponseChunk,
     SupportedLanguage,
-    SwitchCLIChatRequest,
-    SwitchCLIChatResponse,
-    SystemContextRequest,
-    SystemContextResponse,
 )
 from exponent.core.types.command_data import NaturalEditContent
 from exponent.core.types.event_types import (
@@ -75,85 +59,11 @@ from exponent.core.types.event_types import (
 )
 from exponent.utils.version import get_installed_version
 
+logger = logging.getLogger(__name__)
+
 ### Serde
 
 
-def deserialize_message_data(
-    message_data: RemoteExecutionMessageData | str,
-) -> RemoteExecutionMessage:
-    if isinstance(message_data, str):
-        message_data = RemoteExecutionMessageData.model_validate_json(message_data)
-    if message_data.direction == "request":
-        return deserialize_request_data(cast(RemoteExecutionRequestData, message_data))
-    elif message_data.direction == "response":
-        return deserialize_response_data(
-            cast(RemoteExecutionResponseData, message_data)
-        )
-    else:
-        # type checking trick, if you miss a namespace then
-        # this won't typecheck due to the input parameter
-        # having a potential type other than no-return
-        assert_unreachable(message_data.direction)
-
-
-def deserialize_request_data(
-    request_data: RemoteExecutionRequestData | str,
-) -> RemoteExecutionRequestType:
-    request: RemoteExecutionRequestType
-    if isinstance(request_data, str):
-        request_data = RemoteExecutionRequestData.model_validate_json(request_data)
-    if request_data.direction != "request":
-        raise ValueError(f"Expected request, but got {request_data.direction}")
-    if request_data.namespace == "code_execution":
-        request = CodeExecutionRequest.model_validate_json(request_data.message_data)
-    elif request_data.namespace == "file_write":
-        request = FileWriteRequest.model_validate_json(request_data.message_data)
-    elif request_data.namespace == "list_files":
-        request = ListFilesRequest.model_validate_json(request_data.message_data)
-    elif request_data.namespace == "get_file_attachment":
-        request = GetFileAttachmentRequest.model_validate_json(
-            request_data.message_data
-        )
-    elif request_data.namespace == "get_file_attachments":
-        request = GetFileAttachmentsRequest.model_validate_json(
-            request_data.message_data
-        )
-    elif request_data.namespace == "get_matching_files":
-        request = GetMatchingFilesRequest.model_validate_json(request_data.message_data)
-    elif request_data.namespace == "system_context":
-        request = SystemContextRequest.model_validate_json(request_data.message_data)
-    elif request_data.namespace == "get_all_tracked_files":
-        request = GetAllTrackedFilesRequest.model_validate_json(
-            request_data.message_data
-        )
-    elif request_data.namespace == "command":
-        request = CommandRequest.model_validate_json(request_data.message_data)
-    elif request_data.namespace == "halt":
-        request = HaltRequest.model_validate_json(request_data.message_data)
-    elif request_data.namespace == "streaming_code_execution":
-        request = StreamingCodeExecutionRequest.model_validate_json(
-            request_data.message_data
-        )
-    elif request_data.namespace == "switch_cli_chat":
-        request = SwitchCLIChatRequest.model_validate_json(request_data.message_data)
-    elif request_data.namespace == "streaming_code_execution_chunk":
-        assert False, "Streaming code execution chunk is a response, not a request"
-    elif request_data.namespace == "error":
-        assert False, "Error is a response, not a request"
-    elif request_data.namespace == "create_checkpoint":
-        request = CreateCheckpointRequest.model_validate_json(request_data.message_data)
-    elif request_data.namespace == "rollback_to_checkpoint":
-        request = RollbackToCheckpointRequest.model_validate_json(
-            request_data.message_data
-        )
-    else:
-        # type checking trick, if you miss a namespace then
-        # this won't typecheck due to the input parameter
-        # having a potential type other than no-return
-        request = assert_unreachable(request_data.namespace)
-    return truncate_message(request)
-
-
 def deserialize_response_data(
     response_data: RemoteExecutionResponseData | str,
 ) -> RemoteExecutionResponseType:
@@ -176,30 +86,8 @@ def deserialize_response_data(
         response = FileWriteResponse.model_validate_json(response_data.message_data)
     elif response_data.namespace == "list_files":
         response = ListFilesResponse.model_validate_json(response_data.message_data)
-    elif response_data.namespace == "get_matching_files":
-        response = GetMatchingFilesResponse.model_validate_json(
-            response_data.message_data
-        )
-    elif response_data.namespace == "get_file_attachment":
-        response = GetFileAttachmentResponse.model_validate_json(
-            response_data.message_data
-        )
-    elif response_data.namespace == "get_file_attachments":
-        response = GetFileAttachmentsResponse.model_validate_json(
-            response_data.message_data
-        )
-    elif response_data.namespace == "system_context":
-        response = SystemContextResponse.model_validate_json(response_data.message_data)
-    elif response_data.namespace == "get_all_tracked_files":
-        response = GetAllTrackedFilesResponse.model_validate_json(
-            response_data.message_data
-        )
     elif response_data.namespace == "command":
         response = CommandResponse.model_validate_json(response_data.message_data)
-    elif response_data.namespace == "halt":
-        response = HaltResponse.model_validate_json(response_data.message_data)
-    elif response_data.namespace == "switch_cli_chat":
-        response = SwitchCLIChatResponse.model_validate_json(response_data.message_data)
     elif response_data.namespace == "error":
         response = ErrorResponse.model_validate_json(response_data.message_data)
     elif response_data.namespace == "create_checkpoint":
@@ -229,7 +117,7 @@ def serialize_message(response: RemoteExecutionMessage) -> str:
     return serialized
 
 
-### API Serde
+### API Serdes
 
 
 TModel = TypeVar("TModel", bound=BaseModel)
@@ -240,7 +128,7 @@ async def deserialize_api_response(
     data_model: type[TModel],
 ) -> TModel:
     if response.is_error:
-        print(response.text)
+        logging.error(response.text)
         try:
             error_message = response.json()["detail"]
         except Exception:
@@ -407,27 +295,11 @@ def truncate_message(response: FileWriteRequest) -> FileWriteRequest: ...
 @overload
 def truncate_message(response: FileWriteResponse) -> FileWriteResponse: ...
 @overload
-def truncate_message(
-    response: GetFileAttachmentRequest,
-) -> GetFileAttachmentRequest: ...
-@overload
-def truncate_message(
-    response: GetFileAttachmentResponse,
-) -> GetFileAttachmentResponse: ...
-@overload
 def truncate_message(response: ListFilesRequest) -> ListFilesRequest: ...
 @overload
 def truncate_message(response: ListFilesResponse) -> ListFilesResponse: ...
-@overload
-def truncate_message(response: GetMatchingFilesRequest) -> GetMatchingFilesRequest: ...
-@overload
-def truncate_message(
-    response: GetMatchingFilesResponse,
-) -> GetMatchingFilesResponse: ...
-@overload
-def truncate_message(response: SystemContextRequest) -> SystemContextRequest: ...
-@overload
-def truncate_message(response: SystemContextResponse) -> SystemContextResponse: ...
+
+
 @overload
 def truncate_message(
     response: RemoteExecutionRequestType,
@@ -445,12 +317,9 @@ def truncate_message(
 ) -> RemoteExecutionMessage:
     if isinstance(
         response,
-        (
-            CodeExecutionResponse,
-            GetFileAttachmentResponse,
-            StreamingCodeExecutionResponse,
-            StreamingCodeExecutionResponseChunk,
-        ),
+        CodeExecutionResponse
+        | StreamingCodeExecutionResponse
+        | StreamingCodeExecutionResponseChunk,
     ):
         content, truncated = truncate_output(response.content)
         response.content = content
@@ -464,12 +333,6 @@ def truncate_message(
         response.content = content
         if truncated:
             response.truncated = True
-    elif isinstance(response, GetFileAttachmentsResponse):
-        for file_attachment in response.file_attachments:
-            content, truncated = truncate_output(file_attachment.content)
-            file_attachment.content = content
-            if truncated:
-                file_attachment.truncated = True
     return response
 
 
@@ -577,6 +440,20 @@ async def safe_read_file(path: FilePath) -> str:
         raise
 
 
+async def safe_get_file_metadata(path: FilePath) -> FileMetadata | None:
+    path = AsyncPath(path)
+    try:
+        stats = await path.stat()
+    except Exception as e:
+        logger.error(f"Error getting file metadata: {e!s}")
+        return None
+
+    return FileMetadata(
+        modified_timestamp=stats.st_mtime,
+        file_mode=stat.filemode(stats.st_mode),
+    )
+
+
 async def safe_write_file(path: FilePath, content: str) -> None:
     await AsyncPath(path).write_text(content, encoding="utf-8")
 
