@@ -70,10 +70,10 @@ def get_installer() -> str | Literal["unknown"]:
 
 
 def get_latest_pypi_exponent_version() -> str | None:
-    """Get the latest version of Exponent available on PyPI.
+    """Get the latest version of Indent available on PyPI.
 
     Returns:
-        The newest version of Exponent available on PyPI, or None if an error occurred.
+        The newest version of Indent available on PyPI, or None if an error occurred.
     """
     try:
         return cast(
@@ -93,7 +93,7 @@ def get_latest_pypi_exponent_version() -> str | None:
 
 
 def check_exponent_version() -> tuple[str, str] | None:
-    """Check if there is a newer version of Exponent available on PyPI .
+    """Check if there is a newer version of Indent available on PyPI.
 
     Returns:
         None
@@ -103,7 +103,7 @@ def check_exponent_version() -> tuple[str, str] | None:
         return "1.0.0", "1.0.1"
     installed_version = get_installed_version()
     if installed_version == "unknown":
-        click.secho("Unable to determine current Exponent version.", fg="yellow")
+        click.secho("Unable to determine current Indent version.", fg="yellow")
         return None
 
     if (latest_version := get_latest_pypi_exponent_version()) and Version(
@@ -134,10 +134,7 @@ def _get_upgrade_command_str(version: str) -> str:
 
 
 def _new_version_str(current_version: str, new_version: str) -> str:
-    return (
-        f"\n{click.style('A new Indent version is available:', fg='cyan')} {new_version} (current: {current_version})\n"
-        f"See {click.style('https://docs.indent.com/help_and_resources/troubleshooting#installation-methods', underline=True)} for details.\n"
-    )
+    return f"\n{click.style('A new Indent version is available:', fg='cyan')} {new_version} (current: {current_version})\n"
 
 
 def _windows_new_version_str(current_version: str, new_version: str) -> str:
@@ -158,11 +155,11 @@ def upgrade_exponent(
     new_version: str,
     force: bool,
 ) -> None:
-    """Upgrade Exponent to the passed in version.
+    """Upgrade Indent to the passed in version.
 
     Args:
-        current_version: The current version of Exponent.
-        new_version: The new version of Exponent.
+        current_version: The current version of Indent.
+        new_version: The new version of Indent.
         force: Whether to force the upgrade without prompting for confirmation.
 
     Returns:
@@ -197,7 +194,7 @@ def upgrade_exponent(
 
     if result.returncode != 0:
         click.secho(
-            "\nFailed to upgrade Indent. See https://docs.indent.com/help_and_resources/troubleshooting#installation-methods for help, or reach out to team@indent.com",
+            "\nFailed to upgrade Indent. Reach out to team@indent.com for help.",
             fg="red",
         )
         sys.exit(2)
@@ -218,7 +215,7 @@ def _upgrade_thread_worker(
 
     Args:
         upgrade_command: The upgrade command to execute
-        current_version: The current version of Exponent
+        current_version: The current version of Indent
         new_version: The target version to upgrade to
     """
     from exponent.core.remote_execution.session import send_exception_log
@@ -244,11 +241,11 @@ def upgrade_exponent_in_background(
     new_version: str,
     settings: Settings,
 ) -> None:
-    """Upgrade Exponent to the passed in version in a background thread."""
+    """Upgrade Indent to the passed in version in a background thread."""
 
     if not settings.options.auto_upgrade:
         click.secho(
-            "A new version of Exponent is available, but automatic upgrades are disabled. Please upgrade manually using `exponent upgrade`.\n",
+            "A new version of Indent is available, but automatic upgrades are disabled. Please upgrade manually using `indent upgrade`.\n",
             fg="yellow",
         )
         return
